<?php
/**
 * Register filter for append custom class name
 * that generated from visual-composer
 */

/**
 * Register shortcode into Visual Composer
 */
add_action( 'vc_before_init', 'themesflat_client_shortcode_params' );

function themesflat_client_shortcode_params() {
	/**
	 * Map the client slider shortcode
	 */
	vc_map( array(
		'name'                    => esc_html__( 'Themesflat: Client Slider', 'specal' ),
		'base'                    => 'themesflat_client_slider',
		'as_parent'               => array( 'only' => 'themesflat_client' ), 
		'icon'       			  => THEMESFLAT_ICON,
		'content_element'         => true,
		'show_settings_on_create' => false,
		'category'                => esc_html__( 'specal', 'specal' ),
		'params'                  => array(

			array(
				'type'       => 'attach_images',
				'heading'    => esc_html__( 'Images', 'specal' ),
				'param_name' => 'image'
			),
								
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Margin', 'specal' ),
				'param_name' => 'margin',
				'value' => '30',
				'description' => esc_html__( 'Margin item for slide', 'specal' )
			),

			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Slides per view', 'specal' ),
				'param_name' => 'slides_per_view',
				'value' => '5',
				'description' => esc_html__( 'The number of items you want to see on the screen.', 'specal' )
			),

			array(
				'type' => 'checkbox',
				'heading' => esc_html__( 'Slider autoplay', 'specal' ),
				'param_name' => 'autoplay',
				'description' => esc_html__( 'Disable autoplay mode.', 'specal' ),
				'value' => array( esc_html__( 'Yes, please', 'specal' ) => 'yes' )
			),

			array(
				'type' => 'checkbox',
				'heading' => esc_html__( 'Hide pagination control', 'specal' ),
				'param_name' => 'hide_control',
				'description' => esc_html__( 'If YES pagination control will be removed.', 'specal' ),
				'value' => array( esc_html__( 'Yes, please', 'specal' ) => 'yes' )
			),
			
			array(
				'type' => 'checkbox',
				'heading' => esc_html__( 'Hide prev/next buttons', 'specal' ),
				'param_name' => 'hide_buttons',
				'description' => esc_html__( 'If "YES" prev/next control will be removed.', 'specal' ),
				'value' => array( esc_html__( 'Yes, please', 'specal' ) => 'yes' )
			),

			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Extra class name', 'specal' ),
				'param_name' => 'class',
				'description' => esc_html__( 'Your custom class', 'specal' )
			),

			array(
				'type' => 'css_editor',
				'param_name' => 'css',
				'group' => esc_html__( 'Design Options', 'specal' )
			),			
		
			array(
				'type' => 'css_editor',
				'param_name' => 'css',
				'group' => esc_html__( 'Design Options', 'specal' )
			)
		)
		
	) );	
}

add_shortcode( 'themesflat_client_slider', 'themesflat_shortcode_client_slider' );

/**
 * Iconbox shortcode handle
 * 
 * @param   array  $atts  Shortcode attributes
 * @return  void
 */
function themesflat_shortcode_client_slider( $atts, $content = null ) {
	$atts = vc_map_get_attributes( 'themesflat_client_slider', $atts );
	extract (apply_filters( 'themesflat/shortcode/themesflat_client_slider_atts',$atts));
	$config = $atts;
	unset( $config['class'] );
	unset( $config['css'] );
	$class = apply_filters( 'themesflat/shortcode/themesflat_client_slider_class', array( 'themesflat_client_slider_inner', $class ), $atts );

	// Enqueue shortcode assets
	wp_enqueue_script( 'themesflat-carousel' );

	if ( ! empty( $image ) ) {
		if ( is_numeric( $image ) && $image = wp_get_attachment_image_src( $image, 'full' ) )
			$image = array_shift( $image );

			$images = "";

			for($i = 0; $i < count(explode(",",$image)); $i++):	    	

				$images .= sprintf('<div class="themesflat_client-image">'. wp_get_attachment_image(explode(",", $image)[$i]) .'</div>');

			endfor;

	}		
	
	return sprintf( '
		<div class="themesflat_client_slider">
			<div class="%s" data-margin="%s" data-slides_per_view="%s" data-autoplay="%s" data-hide_control="%s" data-hide_buttons="%s">			
				%8$s				
			</div>
		</div>
	', implode( ' ', $class ), esc_attr( $margin) , esc_attr($slides_per_view ), esc_attr( $autoplay ), esc_attr( $hide_control ), esc_attr( $hide_buttons ),  do_shortcode( $content ), $images  );
}

